@@ -36,10 +36,11 @@
 #' @return the estimated tree using the data `XI, XJ`.
 #'
 #'
-#' @references Derumigny, A., Fermanian, J. D., & Min, A. (2020).
+#' @references Derumigny, A., Fermanian, J. D., & Min, A. (2022).
 #' Testing for equality between conditional copulas
 #' given discretized conditioning events.
-#' ArXiv preprint \href{https://arxiv.org/abs/2008.09498}{arxiv:2008.09498}.
+#' Canadian Journal of Statistics.
+#' \doi{10.1002/cjs.11742}
 #'
 #'
 #' @seealso \code{\link{bCond.simpA.CKT}} for a test of the simplifying assumption
@@ -75,7 +76,8 @@
 #' @export
 #'
 bCond.treeCKT <- function(XI, XJ,
-                          minCut = 0, minProb = 0.01, minSize = minProb * length(XI),
+                          minCut = 0, minProb = 0.01,
+                          minSize = minProb * nrow(XI),
                           nPoints_xJ = 10, type.quantile = 7,
                           verbose = 2)
 {
